using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.IO;
using System.Xml;

using Ektron.Cms;
using Ektron.Cms.Controls;
using Ektron.Cms.Controls.ECommerce;
using Ektron.Cms.Controls.ECommerce.Checkout;

public partial class CheckoutDemo_Advanced : System.Web.UI.Page
{
    private const string _CACHE__SKIP_SHIPPING_SELECT_IDENTIFIER = "checkout_demo__skip_ship_method_select";

    protected override void OnInit (EventArgs e)
    {
        //checkout1.ValidatePhase = false; // for full control, but customer could force almost any state unless handled here...
        checkout1.PhaseChange += this.HandlePhaseChange;
        checkout1.PreProcessXml += this.HandlePreProcessXml;
        checkout1.PostProcessXml += this.HandlePostProcessXml;
        checkout1.FilterAjaxCallback += this.HandleFilterAjaxCallback;
        checkout1.PostLogin += this.HandlePostLogin;

        base.OnInit(e);
    }

    protected void Page_Load(object sender, EventArgs e)
    {
    }

    protected void HandlePhaseChange(object sender, PhaseChangeEventArgs e)
    {
        // Allows supervising checkout-control phase-changes:
        // (could set ValidatePhase=false to have complete control).

        // example: skip shipping method select phase:
        if (SkipShippingMethodSelect)
        {
            if (Checkout.ControlPhase.ShippingMethodSelect == e.TargetPhase
                && Checkout.ControlPhase.ShippingInfo == e.CurrentPhase)
                e.TargetPhase = Checkout.ControlPhase.ReviewOrder;
            else if (Checkout.ControlPhase.ShippingMethodSelect == e.TargetPhase
                && Checkout.ControlPhase.ReviewOrder == e.CurrentPhase)
                e.TargetPhase = Checkout.ControlPhase.ShippingInfo;
        }
    }

    protected void HandlePreProcessXml(object sender, EventArgs e)
    {
        try
        {
            // Inspect and/or manipulate XML before XSL transform is run:
            XmlDocument xml = checkout1.XmlDoc;

            // a simple example that sets the Billing-Informations company name to the users name, if provided...
            string usersFirstName = "A valued customer";
            XmlNodeList nodeList;
            if (null != checkout1.XmlDoc)
            {
                nodeList = checkout1.XmlDoc.SelectNodes("/root/userInfo/firstName");
                if (nodeList != null)
                {
                    usersFirstName = nodeList[0].InnerText;
                }

                nodeList = checkout1.XmlDoc.SelectNodes("/root/dataMode");
                if (nodeList != null)
                {
                    if ("BillingInfo" == nodeList[0].InnerText)
                    {
                        nodeList = checkout1.XmlDoc.SelectNodes("/root/billingInfo/company");
                        if (nodeList != null)
                            nodeList[0].InnerText = usersFirstName + "'s company (see demo code behind)";
                    }
                }
            }
        }
        catch { }
    }

    protected void HandlePostProcessXml(object sender, EventArgs e)
    {
        // Manipulate Text-output here, before rendering (XSL transform has completed):

        // a simple replacement example:
        checkout1.Text = checkout1.Text.Replace("Please enter your billing information", "To better service your order, please enter your billing information");
    }

    protected void HandleFilterAjaxCallback(object sender, FilterAjaxCallbackEventArgs e)
    {
        string callbackParameters = e.EventArgs;
        // could inspect or override / filter the callback parameters...
        //e.EventArgs = "__opcode=rebuildpage";
        e.EventArgs = callbackParameters;
    }

    protected void HandlePostLogin(object sender, PostLoginEventArgs e)
    {
        UserData userData = e.User;
        // could make API calls with user info at this point...
    }

    protected void SkipShippingMethod_CheckedChanged(object sender, EventArgs e)
    {
        // store checkbox value for reference during ajax callback:
        SkipShippingMethodSelect = SkipShippingMethod.Checked;
    }

    protected bool SkipShippingMethodSelect
    {
        get
        {
            bool result = false;
            try
            {
                if (null != HttpContext.Current.Session[_CACHE__SKIP_SHIPPING_SELECT_IDENTIFIER])
                    result = (bool)HttpContext.Current.Session[_CACHE__SKIP_SHIPPING_SELECT_IDENTIFIER];
            }
            catch { result = false; }
            return result;
        }
        set 
        {
            HttpContext.Current.Session[_CACHE__SKIP_SHIPPING_SELECT_IDENTIFIER] = value;
        }
    }
}
